==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/InsertPositionFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class InsertPositionFluentImpl<A extends InsertPositionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements InsertPositionFluent<A>{

    private Index index;
    private String relativeTo;

    public InsertPositionFluentImpl(){
    }
    public InsertPositionFluentImpl(InsertPosition instance){
            this.withIndex(instance.getIndex()); 
            this.withRelativeTo(instance.getRelativeTo()); 
    }

    public Index getIndex(){
            return this.index;
    }

    public A withIndex(Index index){
            this.index=index; return (A) this;
    }

    public Boolean hasIndex(){
            return this.index != null;
    }

    public String getRelativeTo(){
            return this.relativeTo;
    }

    public A withRelativeTo(String relativeTo){
            this.relativeTo=relativeTo; return (A) this;
    }

    public Boolean hasRelativeTo(){
            return this.relativeTo != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            InsertPositionFluentImpl that = (InsertPositionFluentImpl) o;
            if (index != null ? !index.equals(that.index) :that.index != null) return false;
            if (relativeTo != null ? !relativeTo.equals(that.relativeTo) :that.relativeTo != null) return false;
            return true;
    }




}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/InsertPositionFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class InsertPositionFluentImpl<A extends InsertPositionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements InsertPositionFluent<A>{

    private Index index;
    private String relativeTo;

    public InsertPositionFluentImpl(){
    }
    public InsertPositionFluentImpl(InsertPosition instance){
            this.withIndex(instance.getIndex()); 
            this.withRelativeTo(instance.getRelativeTo()); 
    }

    public Index getIndex(){
            return this.index;
    }

    public A withIndex(Index index){
            this.index=index; return (A) this;
    }

    public Boolean hasIndex(){
            return this.index != null;
    }

    public String getRelativeTo(){
            return this.relativeTo;
    }

    public A withRelativeTo(String relativeTo){
            this.relativeTo=relativeTo; return (A) this;
    }

    public Boolean hasRelativeTo(){
            return this.relativeTo != null;
    }

    public A withNewRelativeTo(String arg1){
            return (A)withRelativeTo(new String(arg1));
    }

    public A withNewRelativeTo(StringBuilder arg1){
            return (A)withRelativeTo(new String(arg1));
    }

    public A withNewRelativeTo(StringBuffer arg1){
            return (A)withRelativeTo(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            InsertPositionFluentImpl that = (InsertPositionFluentImpl) o;
            if (index != null ? !index.equals(that.index) :that.index != null) return false;
            if (relativeTo != null ? !relativeTo.equals(that.relativeTo) :that.relativeTo != null) return false;
            return true;
    }




}
